@@ -4,10 +4,10 @@ ardlBoundOrders <- function(data = NULL , formula = NULL, ic = c("AIC", "BIC", "
   if (is.null(formula)) stop("A formula object showing the dependent and indepdenent series must be entered.")
   vars <- all.vars(formula)
   NumVar <- length(vars)
-  
+  if (NumVar == 2){FullSearch = FALSE}
   diffData <- apply(data , 2 , diff)
   colnames(diffData) <- paste0("d" , colnames(diffData))
-  
+
   data <- cbind(data[2:nrow(data),],diffData)
   
   formula1 <- as.formula(paste0("d" , vars[1] , " ~ " , paste(c(vars , 
@@ -35,9 +35,9 @@ ardlBoundOrders <- function(data = NULL , formula = NULL, ic = c("AIC", "BIC", "
         } else if (ic == "BIC"){
           IC <- BIC(modelFull$model)
         } else if (ic == "MASE"){
-          IC <- MASE(modelFull)
+          IC <- MASE(modelFull)$MASE
         } else if (ic == "GMRAE"){
-          IC <- GMRAE(modelFull)
+          IC <- GMRAE(modelFull)$GMRAE
         } 
         if ( !is.nan(IC) & !is.infinite(IC) ){
           crit[p,q] <- IC
@@ -94,31 +94,36 @@ ardlBoundOrders <- function(data = NULL , formula = NULL, ic = c("AIC", "BIC", "
         } else if (ic == "BIC"){
           crit[i] <- BIC(modelFull$model)
         } else if (ic == "MASE"){
-          crit[i] <- MASE(modelFull)
+          crit[i] <- MASE(modelFull)$MASE
         } else if (ic == "GMRAE"){
-          crit[i] <- GMRAE(modelFull)
+          crit[i] <- GMRAE(modelFull)$GMRAE
         } 
       }
-      crit <- unlist(crit)
+      # crit <- unlist(crit)
       combs.p <- data.frame(combs[1:(nrow(combs)-1),],crit)
       colnames(combs.p)[ncol(combs.p)] <- "Stat"
       p <- data.frame(combs[which(crit == min(crit, na.rm = TRUE) , arr.ind = TRUE), ])
       colnames(p) <- vars[2:NumVar] 
       
-      return( list(p = p , q = q , Stat.table = crit.pq , min.Stat = min(crit.pq , na.rm = TRUE) , Stat.p = combs.p[order(combs.p$Stat), ]) )
+      return( list(p = p , q = q , Stat.table = crit.pq , min.Stat = min(crit , na.rm = TRUE) , Stat.p = combs.p[order(combs.p$Stat), ]) )
       
     } else {
       p <- as.data.frame(t(rep(p , NumVar - 1)))
       colnames(p) <- vars[2:NumVar] 
-        return( list(p = p , q = q , Stat.table = crit.pq, min.Stat = min(crit.pq , na.rm = TRUE)) )
+      return( list(p = p , q = q , Stat.table = crit.pq, min.Stat = min(crit.pq , na.rm = TRUE)) )
     }
   } else {
+
     crit <- array(NA, 500000)
     orders <- array(NA, dim =c(500000, NumVar))
-    for (p in 1:(max.p+1)){  
-      combs <- data.frame(1:p)
-      for ( i in 2:(NumVar - 1)){
-        combs <- data.frame(combs, 1:p)
+    # for (p in 1:(max.p + 1)){  # max.p+1 is to include 0
+      # combs <- data.frame(1:p)
+      combs <- data.frame(1:max.p)
+      if (NumVar > 2){
+        for ( i in 2:(NumVar - 1)){
+          # combs <- data.frame(combs, 1:p)
+          combs <- data.frame(combs, 1:max.p)
+        }
       }
       combs <- expand.grid(combs)
       colnames(combs) <- vars[2:NumVar]
@@ -150,18 +155,31 @@ ardlBoundOrders <- function(data = NULL , formula = NULL, ic = c("AIC", "BIC", "
           } else if (ic == "BIC"){
             crit[count] <- BIC(modelFull$model)
           } else if (ic == "MASE"){
-            crit[count] <- MASE(modelFull)
+            crit[count] <- MASE(modelFull)$MASE
           } else if (ic == "GMRAE"){
-            crit[count] <- GMRAE(modelFull)
+            crit[count] <- GMRAE(modelFull)$GMRAE
           } 
         }
       }
+    # }
+    crit <- crit[1:count]
+    if (!is.finite(min(crit))){
+      stop("The minimum value of the criterion returns -inf! Please change the max.p and max.q and try again.")
     }
-    crit <- unlist(crit[1:count])
-    best.order <- orders[which(crit == min(crit) , arr.ind = TRUE),]
-    p <- data.frame(t(best.order[1:(length(best.order)-1)]))
+    orders <- orders[1:count,]
+
+    if (sum(crit == min(crit)) > 1){
+      best.order <- orders[which(crit == min(crit) , arr.ind = TRUE)[1],]
+      p <- data.frame(best.order[1])
+    } else {
+      best.order <- orders[which(crit == min(crit) , arr.ind = TRUE),]
+      p <- data.frame(t(best.order[1:(length(best.order)-1)]))
+    }  
+    
     colnames(p) <- vars[2:NumVar] 
     q <- best.order[length(best.order)]
-    return( list(p = p , q = q, Stat.table = crit, min.Stat = min(crit, na.rm = TRUE)))
+    Stat.table <- data.frame(orders , crit)
+    colnames(Stat.table) <- c(colnames(combs), "q", ic)
+    return( list(p = p , q = q, Stat.table = Stat.table, min.Stat = min(crit, na.rm = TRUE)))
   }
 }
